diff --git a/man/readNWISpeak.Rd b/man/readNWISpeak.Rd
index d6753d40c029b6ec2e4033017838c564b4a97b1c..548cb93df0f1cb8cf60df3c44b59323fdc8bf433 100644
--- a/man/readNWISpeak.Rd
+++ b/man/readNWISpeak.Rd
@@ -30,10 +30,10 @@ peak_va \tab numeric \tab Annual peak streamflow value in cfs \cr
 peak_cd \tab character \tab Peak Discharge-Qualification codes (see \code{comment} for more information) \cr
 gage_ht \tab numeric \tab Gage height for the associated peak streamflow in feet \cr
 gage_ht_cd \tab character \tab Gage height qualification codes \cr
-year_last_pk \tab character \tab Peak streamflow reported is the highest since this year \cr
-ag_dt \tab character \tab Date of maximum gage-height for water year (if not concurrent with peak) \cr
+year_last_pk \tab numeric \tab Peak streamflow reported is the highest since this year \cr
+ag_dt \tab Date \tab Date of maximum gage-height for water year (if not concurrent with peak) \cr
 ag_tm \tab character \tab Time of maximum gage-height for water year (if not concurrent with peak) \cr
-ag_gage_ht \tab character \tab maximum Gage height for water year in feet (if not concurrent with peak) \cr
+ag_gage_ht \tab numeric \tab maximum Gage height for water year in feet (if not concurrent with peak) \cr
 ag_gage_ht_cd \tab character \tab maximum Gage height code \cr
 }
diff --git a/R/readNWISunit.r b/R/readNWISunit.r
index 1c6957d9949dd144eabdf0f6a5bf279a2ea092c3..201f6177b3d592d24ff6b7a48139ffcf2d6f4c3e 100644
--- a/R/readNWISunit.r
+++ b/R/readNWISunit.r
@@ -101,10 +101,10 @@ readNWISuv <- function (siteNumbers,parameterCd,startDate="",endDate="", tz=""){
 #' peak_cd \tab character \tab Peak Discharge-Qualification codes (see \code{comment} for more information) \cr
 #' gage_ht \tab numeric \tab Gage height for the associated peak streamflow in feet \cr
 #' gage_ht_cd \tab character \tab Gage height qualification codes \cr
 #' year_last_pk \tab character \tab Peak streamflow reported is the highest since this year \cr
 #' ag_dt \tab character \tab Date of maximum gage-height for water year (if not concurrent with peak) \cr
 #' ag_tm \tab character \tab Time of maximum gage-height for water year (if not concurrent with peak) \cr
 #' ag_gage_ht \tab character \tab maximum Gage height for water year in feet (if not concurrent with peak) \cr
 #' ag_gage_ht_cd \tab character \tab maximum Gage height code \cr
 #' }
 #' 
@@ -142,8 +142,11 @@ readNWISpeak <- function (siteNumbers,startDate="",endDate="", asDateTime=TRUE){
         }
       }
       data$peak_dt <- as.Date(data$peak_dt)
+      data$ag_dt <- as.Date(data$ag_dt)
     }
     data$gage_ht <- as.numeric(data$gage_ht)
+    data$ag_gage_ht <- as.numeric(data$ag_gage_ht)
+    data$year_last_pk <- as.numeric(data$year_last_pk)
     
     siteInfo <- readNWISsite(siteNumbers)
     siteInfo <- left_join(unique(data[,c("agency_cd","site_no")]),siteInfo, by=c("agency_cd","site_no"))
@@ -101,10 +101,10 @@ readNWISuv <- function (siteNumbers,parameterCd,startDate="",endDate="", tz=""){
 #' gage_ht \tab numeric \tab Gage height for the associated peak streamflow in feet \cr
 #' gage_ht_cd \tab character \tab Gage height qualification codes \cr
-#' year_last_pk \tab character \tab Peak streamflow reported is the highest since this year \cr
-#' ag_dt \tab character \tab Date of maximum gage-height for water year (if not concurrent with peak) \cr
+#' year_last_pk \tab numeric \tab Peak streamflow reported is the highest since this year \cr
+#' ag_dt \tab Date \tab Date of maximum gage-height for water year (if not concurrent with peak) \cr
 #' ag_tm \tab character \tab Time of maximum gage-height for water year (if not concurrent with peak) \cr
@@ -101,10 +101,10 @@ readNWISuv <- function (siteNumbers,parameterCd,startDate="",endDate="", tz=""){
 #' ag_tm \tab character \tab Time of maximum gage-height for water year (if not concurrent with peak) \cr
-#' ag_gage_ht \tab character \tab maximum Gage height for water year in feet (if not concurrent with peak) \cr
+#' ag_gage_ht \tab numeric \tab maximum Gage height for water year in feet (if not concurrent with peak) \cr
 #' ag_gage_ht_cd \tab character \tab maximum Gage height code \cr
 #' }